import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.util.List;

/**
 * Gemeenschappelijke bovenklasse voor voorwerpen die kunnen bewegen.
 * 
 * Bevat de code die de buren bepaalt en de verschillen in X- en Y-coördinaten bij beweging.
 */
public class Beweger extends Actor {
    
    private static int[] D = {0, 1, 0, -1, 0};
    
    /**
     * Hoeveel verandert X als er één stap in de opgegeven richting wordt bewogen?
     * @param richting in graden: (0, 90, 180 of 270)
     */
    private int xVerschil(int richting) {        
        return D[richting/90 + 1];
    }
    
    /**
     * Hoeveel verandert Y als er één stap in de opgegeven richting wordt bewogen?
     * @param richting in graden: (0, 90, 180 of 270)
     */
    private int yVerschil(int richting) {        
        return D[richting/90];        
    }
    
    /**
     * Geeft de buur terug van dit voorwerp in de opgegeven richting (4 stappen ver). Een
     * 'doel' wordt niet als een buur beschouwd.
     * @param richting in graden: (0, 90, 180 of 270)
     * @return de gezochte buur, of null als er geen buur is
     */
    protected Actor buur(int richting) {
        // opgelet een doel en een kist kunnen zich op dezelfde plaats bevinden
        // we kunnen dus niet zomaar  'getOneObject' gebruiken
        List<Actor> lijst = getObjectsAtOffset(4*xVerschil(richting), 4*yVerschil(richting), null);
        for (Actor actor: lijst) {
            if (! (actor instanceof Doel)) {
                return actor;
            }
        }
        return null;
        // Oefening: implementeer dit zonder uit een lus te 'springen': met
        // een while-lus met dubbele conditie
    }
}
